@@ -11,6 +11,7 @@ from sql.conditionals import Case
 from collections import defaultdict
 from itertools import groupby
 
+from trytond.config import config
 from trytond.i18n import gettext
 from trytond.model.exceptions import AccessError, ValidationError
 from ..model import (ModelView, ModelSQL, Workflow, DeactivableMixin, fields,
@@ -34,6 +35,8 @@ __all__ = [
     ]
 logger = logging.getLogger(__name__)
 
+_disable_confirm = config.getboolean('optional',
+    'disable_button_confirmations', default=False)
 
 class ConditionError(ValidationError):
     pass
@@ -932,7 +935,7 @@ class ModelButton(ModelSQL, ModelView):
             attributes = {
                 'string': button.string,
                 'help': button.help,
-                'confirm': button.confirm,
+                'confirm': button.confirm if not _disable_confirm else None,
                 }
         cls._view_attributes_cache.set(key, attributes)
         return attributes
